@@ -127,12 +127,42 @@ def newEntity(user, entityClass, fields):
     url = url_join(API_ROOT, "/api/generic/", entityClass.__entityName__)
     fields = dict(
         filter(lambda field: field[1] is not None, fields.items()))
-    fields['group_id'] = user.activeWorkspace
+
+    if getattr(entityClass, '__hasParentGroup__', False):
+        fields['group_id'] = user.activeWorkspace
+
     r = requests.post(url, headers=headers, json=fields)
     handleError(r)
     return entityClass(json.loads(r.content), user)
 
 
+def newEntities(user, entityClass, items):
+    """
+    Parameters
+    ----------
+    user (obj)
+        The Labstep user.
+    entityClass (class)
+        The Class of the entity to retrieve.
+    items (List[])
+        List of info on entities to create.
+
+    Returns
+    -------
+    entities
+        List of Labstep Entities created.
+    """
+    headers = getHeaders(user)
+    url = url_join(API_ROOT,
+                   "/api/generic/",
+                   entityClass.__entityName__,
+                   'batch')
+    r = requests.post(url, headers=headers, json={"items": items})
+    handleError(r)
+    entities = json.loads(r.content)
+    return list(map(lambda entity: entityClass(entity, user), entities))
+
+
 def editEntity(entity, fields):
     """
     Parameters
@@ -174,6 +204,9 @@ class Entity:
         return pp.pformat(entity_attributes)
 
     def update(self):
-        return update(self, getEntity(self.__user__,
-                                      type(self),
-                                      self.id).__data__)
+        """
+        Fetches the most up-to-date version of the entity from Labstep.
+        """
+        data = getEntity(self.__user__, type(self), self.id).__data__
+        self.__init__(data, self.__user__)
+        return self
