@@ -5,8 +5,9 @@ from .primaryEntity import PrimaryEntity
 from .entity import getEntity, getEntities, newEntity, editEntity
 from .helpers import getTime
 from .metadata import addMetadataTo, getMetadata
-from .resourceItem import getResourceItems, newResourceItem
+from .resourceItem import getResourceItems, newResourceItem, ResourceItem
 from .orderRequest import newOrderRequest
+from .resourceCategory import getResourceCategory
 
 
 def getResource(user, resource_id):
@@ -104,7 +105,7 @@ def editResource(resource, name=None, deleted_at=None,
         An object representing the edited Resource.
     """
     params = {'name': name,
-              'resource_category_id': resource_category_id,
+              'template_id': resource_category_id,
               'deleted_at': deleted_at,
               **extraParams}
     return editEntity(resource, params)
@@ -224,6 +225,27 @@ class Resource(PrimaryEntity):
         """
         return getMetadata(self)
 
+    def getResourceCategory(self):
+        """
+        Get the ResourceCategory of the Resource.
+
+        Returns
+        -------
+        :class:`~labstep.resourceCategory.ResourceCategory`
+            An object representing the Resource Category on Labstep.
+
+        Example
+        -------
+        ::
+
+            # Get a Resource
+            resource = user.getResource(170)
+
+            # Get the Resource Category of the resource
+            resourceCategory = resource.getResourceCategory()
+        """
+        return getResourceCategory(self.__user__, self.template['id'])
+
     def setResourceCategory(self, resource_category_id, extraParams={}):
         """
         Add a Labstep ResourceCategory to a Resource.
@@ -350,3 +372,72 @@ class Resource(PrimaryEntity):
                                quantity_unit=quantity_unit,
                                resource_location_id=resource_location_id,
                                extraParams=extraParams)
+
+    def getItemTemplate(self):
+        '''
+        Get the template used for initialising new items of the resource.
+
+        Returns
+        -------
+        :class:`~labstep.resourceItem.ResourceItem`
+            An object representing a ResourceItem on Labstep.
+
+        Example
+        -------
+        ::
+
+            my_resource = user.getResource(17000)
+            itemTemplate = my_resource.getItemTemplate()
+
+            itemTemplate.addMetadata('Expiry Date')
+
+        '''
+        self.update()
+        if self.resource_item_template is None:
+            return None
+
+        return ResourceItem(self.resource_item_template, self.__user__)
+
+    def enableCustomItemTemplate(self):
+        '''
+        Enable a custom item template for this resource.
+        If disabled the template for the Resource Category will be used.
+
+        Returns
+        -------
+        None
+
+        Example
+        -------
+        ::
+
+            my_resource = user.getResource(17000)
+            my_resource.enableCustomItemTemplate()
+
+            itemTemplate = my_resource.getItemTemplate()
+
+            itemTemplate.addMetadata('Expiry Date')
+
+        '''
+        if self.resource_item_template is None:
+            self.newItem(extraParams={'is_template': 1})
+        else:
+            self.getItemTemplate().edit(extraParams={'deleted_at': None})
+
+    def disableCustomItemTemplate(self):
+        '''
+        Disable custom item template for this resource.
+        If disabled the template for the Resource Category will be used.
+
+        Returns
+        -------
+        None
+
+        Example
+        -------
+        ::
+
+            my_resource = user.getResource(17000)
+            my_resource.disableCustomItemTemplate()
+        '''
+        self.getItemTemplate().delete()
